#!/bin/bash
# mysql insert test

readonly HOST=${1-"localhost"}
readonly USER=${2-"root"}
readonly PASSWD=${3-""}
readonly TIMEOUT=${4-3600}
readonly TEST_DB=ping_test
readonly CMDNAME=`basename $0`

setUp() {
	csv_echo "setUp"
	mysql -u $USER -p$PASSWD -h $HOST -e "
create database IF NOT EXISTS $TEST_DB default character set utf8;
use $TEST_DB;
CREATE TABLE IF NOT EXISTS test (
 id int(11),
 created_at datetime DEFAULT NULL,
 PRIMARY KEY (id)
) ENGINE=InnoDB;
"
	if [ $? != 0 ]; then
		echo -e "ERROR\tcreate table $TEST_DB"  1>&2
		exit 1
	fi
}

tearDown() {
	csv_echo "tearDown"
	mysql -u $USER -p$PASSWD -h $HOST -e "
drop database IF EXISTS $TEST_DB;
"
	if [ $? != 0 ]; then
		echo -e "ERROR\tdrop table $TEST_DB"  1>&2
		exit 1
	fi
}

csv_header() {
	echo "datetime,function,is_up,is_down,down time(sec)"
}

csv_echo() {
	local date_time=$(date --iso-8601=seconds)
	echo "$date_time,$@"
}

write_loop() {
	local max_wait_sec=$TIMEOUT
	local wait_sec=1
	local mysqladmin=/usr/bin/mysqladmin
	local start_sec=$SECONDS
	local end_sec=$SECONDS
	local i=1
	local down_time=0

	while [ $(( $end_sec - $start_sec )) -le $max_wait_sec ]; do
		local is_up=0
		local is_down=0
		mysql -u $USER -p$PASSWD -h $HOST -e "
insert into test (id, created_at) values ($i, '$now');
" $TEST_DB

		if [ $? == 0 ]; then
			is_up=1
		else
			is_down=1
		fi
		sleep $wait_sec
		end_sec=$SECONDS
		if [ "$is_down" == "1" ]; then
			down_time=$(( $down_time + 1 ))
			csv_echo "write_loop,$is_up,$is_down,$down_time"
		fi
		i=$(( $i + 1 ))
	done

	return 0
}

usage_exit() {
    echo "Usage: $CMDNAME <host> <user> <password> [timeout sec] 1>mysql-ping.csv 2>mysql-ping.error.log" 1>&2
    exit 1
}

main () {
	csv_header
	tearDown
	setUp
	
	write_loop
	
	tearDown
}

# check command args.
if [ $# -lt 1 ]; then
    usage_exit
fi

main
